@@ -1,9 +1,10 @@
 
 
 import logging
+import sys
 
 
-__version__ = "1.0.1"
+__version__ = "1.1.0"
 
 SD_EMERG = 0
 SD_ALERT = 1
@@ -33,18 +34,35 @@ class FormattingWrapper:
         self.child = child_formatter
 
     def annotate(self, levelno, text):
-        return "\n".join(
-            "<%i>%s" % (level_to_priority(levelno), line)
-            for line in text.splitlines()
-        )
+        priority = level_to_priority(levelno)
+        return prefix_all_lines(priority, text)
 
     def format(self, record):
         unprefixed = self.child.format(record)
         return self.annotate(record.levelno, unprefixed)
 
 
-def install(logger=None):
+def prefix_all_lines(priority, block_of_text):
+    prefixed = "\n".join(
+        "<%i>%s" % (priority, line)
+        for line in block_of_text.splitlines()
+    )
+    if block_of_text.endswith("\n"):
+        prefixed = prefixed + "\n"
+    return prefixed
+
+
+def excepthook(exc_type, exc_value, exc_tb):
+    import traceback
+    tb_lines = traceback.format_exception(exc_type, exc_value, exc_tb)
+    prefixed_tb_text = prefix_all_lines(SD_ERR, "\n".join(tb_lines))
+    sys.stderr.write(prefixed_tb_text)
+
+
+def install(logger=None, sysexcepthook=True):
     if logger is None:
         logger = logging.root
     for handler in logger.handlers:
         handler.formatter = FormattingWrapper(handler.formatter)
+    if sysexcepthook:
+        sys.excepthook = excepthook
